snapshot_disks
:   A comma-separated list of disks which should be included in a backup
    taken using cloud snapshots. Required when the `snapshot` value
    is specified for `backup_method`.

    Scope: Server/Model.
